@@ -397,20 +397,41 @@ function(year = getRmetricsOptions("currentYear")) {
 # Roxygen Tags
 #' @export
 # ---------------------------------------------------------------------------- #
-GBMayDay =
+## GNB: Early May bank holiday
+# GNB: renaming to the proper name; leaving for now 'GBMayDay' for compatibility
+GBEarlyMayBankHoliday <- 
 function(year = getRmetricsOptions("currentYear")) {
-    ans = .nth.of.nday(year, 5, 1, 1)
-    timeDate(as.character(ans)) }
+    ans = as.character(.nth.of.nday(year, 5, 1, 1))
+
+    ## special: moved to May 8 to celebrate VE Day's 50th/75th anniversary
+    ind <- year %in% c(1995, 2020)
+
+    if(any(ind))
+       ans[ind] <- paste0(year[ind], "0508") # not "-05-08" for consistency with 'ans'
+
+    timeDate(ans)
+}
 
 # ---------------------------------------------------------------------------- #
 # Roxygen Tags
 #' @export
 # ---------------------------------------------------------------------------- #
 # YC: Note GBBankHoliday returns Spring Bank Holiday
-GBBankHoliday =
+# GNB: renaming to the proper name; leaving for now 'GBBankHoliday' for compatibility
+GBSpringBankHoliday <- 
 function(year = getRmetricsOptions("currentYear")) {
-    ans = .last.of.nday(year, 5, 31, 1)
-    timeDate(as.character(ans)) }
+    ans = as.character(.last.of.nday(year, 5, 31, 1))
+    
+    ## moved to be the day before XXX/Diamond/Platinum Jubilee bank holiday
+    ind <- year %in% c(2002, 2012, 2022)
+    if(any(ind)) {
+        ans[year == 2002] <- "20020603"
+        ans[year == 2012] <- "20120604"
+        ans[year == 2022] <- "20220602" # Thursday
+    }
+    
+    timeDate(ans)
+}
 
 # ---------------------------------------------------------------------------- #
 # Roxygen Tags
@@ -1166,4 +1187,8 @@ function(year = getRmetricsOptions("currentYear")) {
 
 
 ################################################################################
+## GNB: compatibility
+
+GBMayDay <- GBEarlyMayBankHoliday
+GBBankHoliday <- GBSpringBankHoliday
 
