@@ -24,7 +24,10 @@
 #  skewness.POSIXlt          Method for objects of class POSIXlt
 ################################################################################
 
-
+# ---------------------------------------------------------------------------- #
+# Roxygen Tags
+#' @export
+# ---------------------------------------------------------------------------- #
 skewness <-
     function (x, ...)
 {
@@ -37,9 +40,10 @@ skewness <-
 }
 
 
-# ------------------------------------------------------------------------------
-
-
+# ---------------------------------------------------------------------------- #
+# Roxygen Tags
+#' @export
+# ---------------------------------------------------------------------------- #
 skewness.default <-
     function (x, na.rm = FALSE, method = c("moment", "fisher"), ...)
 {
@@ -89,24 +93,30 @@ skewness.default <-
 }
 
 
-# ------------------------------------------------------------------------------
-
-
+# ---------------------------------------------------------------------------- #
+# Roxygen Tags
+#' @export
+# ---------------------------------------------------------------------------- #
 skewness.data.frame <-
-    function (x, ...)
+    function (x, na.rm = FALSE, method = c("moment", "fisher"), ...)
 {
     # A function implemented by Diethelm Wuertz
+    ## Amended by Georgi N. Boshnakov to set attribute 'method' as documented.
+    ## (changed the signature from (x, ...) to make this straightforward)
 
     # FUNCTION:
+    method <- match.arg(method)
 
     # Return Value:
-    sapply(x, skewness, ...)
+    structure(sapply(x, skewness, na.rm = na.rm, method = method, ...),
+              method = method)
 }
 
 
-# ------------------------------------------------------------------------------
-
-
+# ---------------------------------------------------------------------------- #
+# Roxygen Tags
+#' @export
+# ---------------------------------------------------------------------------- #
 skewness.POSIXct <-
     function (x, ...)
 {
@@ -119,9 +129,10 @@ skewness.POSIXct <-
 }
 
 
-# ------------------------------------------------------------------------------
-
-
+# ---------------------------------------------------------------------------- #
+# Roxygen Tags
+#' @export
+# ---------------------------------------------------------------------------- #
 skewness.POSIXlt <-
     function (x, ...)
 {
